@@ -5,16 +5,17 @@ Module of SqlFilter class.
 
 __author__ = 'https://github.com/akvilary'
 
+from typing import Self
+
 from .sql_container import SqlContainer
 from .utils.classes.filter_operator_manager import FilterOperatorManager
 from .utils.classes.string_convertible import StringConvertible
-from .utils.classes.container_convertible import ContainerConvertible
 
 
 class SqlWrap(
+    SqlContainer,
     FilterOperatorManager,
     StringConvertible,
-    ContainerConvertible,
 ):
     """The class is invented to do wrapping of sql text more easier"""
 
@@ -29,20 +30,15 @@ class SqlWrap(
             - text: str - text to be wrapped
             - wrapper_text: str - string to be added after parentheses enclosing "text" argument.
         """
-        self.text = text
-        self.wrapper_text = wrapper_text or ''
+        SqlContainer.__init__(self, text)
+        self.wrap(wrapper_text)
 
-    def __str__(self):
-        return str(SqlContainer(self.text).wrap(self.wrapper_text))
+    def inline(self) -> Self:
+        """Set inline option"""
+        self.is_multiline_wrap_type = False
+        return self
 
-    def __call__(self, **kwargs):
-        container = self.multiline()
-        return ContainerConvertible.__call__(self, container, **kwargs)
-
-    def inline(self) -> SqlContainer:
-        """Get container of wrapped sql text in inline"""
-        return SqlContainer(self.text).wrap(self.wrapper_text, multiline=False)
-
-    def multiline(self) -> SqlContainer:
-        """Get container of wrapped sql text in multiline"""
-        return SqlContainer(self.text).wrap(self.wrapper_text)
+    def multiline(self) -> Self:
+        """Set inline option"""
+        self.is_multiline_wrap_type = True
+        return self
